@@ -65,6 +65,10 @@ public enum PasswordExceptionCode implements OXExceptionCode {
      * Cannot change password for any reason.
      */
     PASSWORD_FAILED(PasswordExceptionMessage.PASSWORD_FAILED_MSG, CATEGORY_PERMISSION_DENIED, 1),
+    /**
+     * Cannot change password: %1$s
+     */
+    PASSWORD_FAILED_WITH_MSG(PasswordExceptionMessage.PASSWORD_FAILED_WITH_MSG_MSG, CATEGORY_PERMISSION_DENIED, 1),
     /**
      * New password too short.
      */
